@@ -16,6 +16,7 @@ import shutil
 
 import console
 import common
+import settings
 
 ##############################################################################
 # Methods
@@ -45,8 +46,6 @@ def parse_arguments():
     parser.add_argument('--list-toolchains', action='store_true', help='list all currently available toolchain modules [false]')
     parser.add_argument('--list-platforms', action='store_true', help='list all currently available platform modules [false]')
     parser.add_argument('--track', action='store', default=None, help='retrieve rosinstalls relevant to this track [groovy|hydro][groovy]')
-    parser.add_argument('--get-default-track', action='store_true', help='print the default track that is being followed to screen')
-    parser.add_argument('--set-default-track', action='store', default=None, help='set a new default track to work from %s' % common.VALID_TRACKS)
     args = parser.parse_args()
     return args
 
@@ -93,32 +92,20 @@ def instantiate_template(filename, name, cwd):
         f.close()
 
 
-def fill_in_makefile(template, rel_source_dir, catkin_make, catkin_python_path, toolchain, override):
+def fill_in_config_cmake(template, config_build_type, config_install_prefix, config_underlays, config_override_file):
     return template % locals()
 
 
-def instantiate_makefile(filename, build_dir, rel_source_dir, catkin_make, catkin_python_path, toolchain):
-    template_dir = os.path.join(os.path.dirname(__file__), 'templates', 'init_build')
-    tmpl = read_template(os.path.join(template_dir, filename))
-    contents = fill_in_makefile(tmpl, rel_source_dir, catkin_make, catkin_python_path, toolchain, common.override_filename())
-    try:
-        f = open(os.path.join(build_dir, filename), 'w')
-        f.write(contents.encode('utf-8'))
-    finally:
-        f.close()
-
-
-def fill_in_config_cmake(template, config_install_prefix, config_underlays):
-    return template % locals()
-
-
-def instantiate_config_cmake(build_path, config_install_prefix, config_underlays):
+def instantiate_config_cmake(platform_content, build_path, config_build_type, config_install_prefix, config_underlays):
     '''
       Copy the cache configuration template to the build path.
+
+      @param platform_content : content to prepend to the default configuration file
+      @param build_path : location of the build directory to save the config.cmake file.
     '''
     template_dir = os.path.join(os.path.dirname(__file__), 'cmake')
     template = read_template(os.path.join(template_dir, "config.cmake"))
-    contents = fill_in_config_cmake(template, config_install_prefix, config_underlays)
+    contents = fill_in_config_cmake(template, config_build_type, config_install_prefix, config_underlays, common.override_filename())
     config_cmake_file = os.path.join(build_path, "config.cmake")
     try:
         f = open(config_cmake_file, 'w')
@@ -128,7 +115,7 @@ def instantiate_config_cmake(build_path, config_install_prefix, config_underlays
 
 
 def print_build_details(build_dir, source_dir, install_prefix, build_type, underlays, name, toolchain, platform):
-    console.pretty_println("*********** Parallel Development Workspace Details ***********", console.bold)
+    console.pretty_println("************************** Parallel Buildspace Details ***************************", console.bold)
     console.pretty_print("Build directory : ", console.cyan)
     console.pretty_println(build_dir, console.yellow)
     console.pretty_print("Source directory: ", console.cyan)
@@ -147,23 +134,23 @@ def print_build_details(build_dir, source_dir, install_prefix, build_type, under
     if not platform == "":
         console.pretty_print("Platform        : ", console.cyan)
         console.pretty_println(platform, console.yellow)
-    console.pretty_println("**************************************************************", console.bold)
+    console.pretty_println("**********************************************************************************", console.bold)
 
 
 def list_toolchains():
-    console.pretty_println("********************** Toolchain List ************************", console.bold)
+    console.pretty_println("******************************** Toolchain List **********************************", console.bold)
     for (unused_dirpath, unused_dirname, filenames) in os.walk(os.path.join(os.path.dirname(__file__), 'toolchains')):
         for filename in filenames:
             print(" -- %s" % os.path.splitext(os.path.basename(filename))[0])
-    console.pretty_println("**************************************************************", console.bold)
+    console.pretty_println("**********************************************************************************", console.bold)
 
 
 def list_platforms():
-    console.pretty_println("*********************** Platform List ************************", console.bold)
+    console.pretty_println("********************************* Platform List **********************************", console.bold)
     for (unused_dirpath, unused_dirname, filenames) in os.walk(os.path.join(os.path.dirname(__file__), 'platforms')):
         for filename in filenames:
             print(" -- %s" % os.path.splitext(os.path.basename(filename))[0])
-    console.pretty_println("**************************************************************", console.bold)
+    console.pretty_println("**********************************************************************************", console.bold)
 
 
 def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt/ros/groovy", install_prefix_="./install", release_=False, toolchain_="", platform_=""):
@@ -195,11 +182,6 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
     ##########################
     # Source directory
     ##########################
-    # Absolute path - should probably use os.path.abspath here
-    #if os.path.isabs(source_dir_):
-    #    source_dir = source_dir_
-    #else:
-    #    source_dir = os.path.join(os.getcwd(), source_dir_)
     source_dir = os.path.abspath(source_dir_)
     build_source_dir = os.path.join(build_dir, 'src')
     if not os.path.isdir(source_dir):
@@ -212,46 +194,58 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
         if not source_dir == build_source_dir:
             console.error("The build directory already has a ./src directory which doesn't match the desired source directory [%s]" % source_dir)
             sys.exit(1)
-    else:  # create a symlink to the sources
-        common.symlink_dir(source_dir, build_source_dir)
+    else:
+        os.mkdir(build_source_dir)
+        source_subdirectories = os.walk(source_dir).next()[1]
+        for d in source_subdirectories:
+            common.create_symlink(os.path.join(source_dir, d), os.path.join(build_source_dir, d))
 
     ##########################
     # Underlays
     ##########################
-    env_underlays = os.environ['CMAKE_PREFIX_PATH']
+    try:
+        env_underlays = os.environ['CMAKE_PREFIX_PATH']
+    except KeyError:
+        env_underlays = ""
     underlays_list = underlays_.split(';')
     env_underlays_list = env_underlays.split(':')
     for underlay in env_underlays_list:
         if underlay not in underlays_list:
             underlays_list.append(underlay)
-    catkin_found = False
-    for underlay in underlays_list:
-        if os.path.isfile(os.path.join(underlay, 'bin', 'catkin_make')):
-            catkin_make = os.path.join(underlay, 'bin', 'catkin_make')
-            catkin_python_path = os.path.join(underlay, 'lib', 'python2.7', 'dist-packages')
-            catkin_found = True
-            break
-    if not catkin_found:
+
+    ##########################
+    # Locate Catkin
+    ##########################
+    catkin_toplevel = None
+    if os.path.isfile(os.path.join(source_dir, 'catkin', 'cmake', 'toplevel.cmake')):
+        catkin_toplevel = os.path.join(source_dir, 'catkin', 'cmake', 'toplevel.cmake')
+    else:
+        catkin_toplevel, unused_catkin_python_path = common.find_catkin(underlays_list)
+
+    ##########################
+    # Add toplevel if exists
+    ##########################
+    if not catkin_toplevel:
         # Add the default track underlay
-        default_track = common.get_default_track()
-        if os.path.isfile(os.path.join("/opt/ros/%s" % default_track, 'bin', 'catkin_make')):
-            console.pretty_println("No catkin found, adding the default track underlay [/opt/ros/%s]" % default_track)
+        default_track = settings.get_default_track()
+        if os.path.isfile(os.path.join("/opt/ros/%s" % default_track, 'share', 'catkin', 'cmake', 'toplevel.cmake')):
+            catkin_toplevel = os.path.join("/opt/ros/%s" % default_track, 'share', 'catkin', 'cmake', 'toplevel.cmake')
+            unused_catkin_python_path = os.path.join("/opt/ros/%s" % default_track, 'lib', 'python2.7', 'dist-packages')
+            console.pretty_println("No catkin found, adding the default track underlay (use yujin_tools_settings to change) [/opt/ros/%s]" % default_track)
             underlays_list.append("/opt/ros/%s" % default_track)
-            catkin_make = os.path.join("/opt/ros/%s" % default_track, 'bin', 'catkin_make')
-            catkin_python_path = os.path.join("/opt/ros/%s" % default_track, 'lib', 'python2.7', 'dist-packages')
         else:
             console.logerror("Could not find an underlying catkin installation.")
+            sys.exit(1)
+    common.create_symlink(catkin_toplevel, os.path.join(build_source_dir, "CMakeLists.txt"))
     underlays = ';'.join(underlays_list)
 
     ##########################
     # Toolchain
     ##########################
-    toolchain = toolchain_
     if not toolchain_ == "":
         toolchains_dir = os.path.join(os.path.dirname(__file__), 'toolchains')
         if os.path.isfile(os.path.join(toolchains_dir, toolchain_ + ".cmake")):
             shutil.copy(os.path.join(toolchains_dir, toolchain_ + ".cmake"), os.path.join(build_dir, "toolchain.cmake"))
-            toolchain = toolchain = "-DCMAKE_TOOLCHAIN_FILE=toolchain.cmake"
 
     ##########################
     # Platform
@@ -280,7 +274,7 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
     ##########################
     # Cache
     ##########################
-    instantiate_config_cmake(build_dir, install_prefix, underlays)
+    instantiate_config_cmake(build_dir, build_type, install_prefix, underlays)
 
     ##########################
     # Templates
@@ -289,7 +283,6 @@ def init_configured_build(build_dir_="./", source_dir_="./src", underlays_="/opt
     instantiate_template('konsole', name, build_dir)
     instantiate_template('gnome-terminal', name, build_dir)
     instantiate_template('eclipse', name, build_dir)
-    instantiate_makefile('Makefile', build_dir, os.path.relpath(source_dir, build_dir), catkin_make, catkin_python_path, toolchain)
 
 
 def init_build():
@@ -297,16 +290,8 @@ def init_build():
     ##########################
     # Tracks
     ##########################
-    if args.get_default_track:
-        console.pretty_print("\nDefault Track: ", console.cyan)
-        console.pretty_println("%s\n" % common.get_default_track(), console.yellow)
-        sys.exit(0)
-    if args.set_default_track:
-        console.pretty_print("\nNew Default Track: ", console.cyan)
-        console.pretty_println("%s\n" % common.set_default_track(args.set_default_track), console.yellow)
-        sys.exit(0)
     if not args.track:
-        args.track = common.get_default_track()
+        args.track = settings.get_default_track()
     ##########################
     # Toolchains and Platform
     ##########################
